@@ -1,7 +1,7 @@
 __author__ = 'Owais Lone'
-__version__ = '1.4.0'
+__version__ = '1.5.0'
 
 import django
 
 if django.VERSION < (3, 2):  # pragma: no cover
-    default_app_config = 'webpack_loader.apps.WebpackLoaderConfig'
+    default_app_config = "webpack_loader.apps.WebpackLoaderConfig"
