@@ -35,8 +35,8 @@ def _filter_by_extension(bundle, extension):
             yield chunk
 
 
-def _get_bundle(bundle_name, extension, config):
-    bundle = get_loader(config).get_bundle(bundle_name)
+def _get_bundle(loader, bundle_name, extension):
+    bundle = loader.get_bundle(bundle_name)
     if extension:
         bundle = _filter_by_extension(bundle, extension)
     return bundle
@@ -44,7 +44,8 @@ def _get_bundle(bundle_name, extension, config):
 
 def get_files(bundle_name, extension=None, config='DEFAULT'):
     '''Returns list of chunks from named bundle'''
-    return list(_get_bundle(bundle_name, extension, config))
+    loader = get_loader(config)
+    return list(_get_bundle(loader, bundle_name, extension))
 
 
 def get_as_tags(bundle_name, extension=None, config='DEFAULT', suffix='', attrs='', is_preload=False):
@@ -58,8 +59,10 @@ def get_as_tags(bundle_name, extension=None, config='DEFAULT', suffix='', attrs=
     :return: a list of formatted tags as strings
     '''
 
-    bundle = _get_bundle(bundle_name, extension, config)
+    loader = get_loader(config)
+    bundle = _get_bundle(loader, bundle_name, extension)
     tags = []
+
     for chunk in bundle:
         if chunk['name'].endswith(('.js', '.js.gz')):
             if is_preload:
@@ -68,12 +71,21 @@ def get_as_tags(bundle_name, extension=None, config='DEFAULT', suffix='', attrs=
                 ).format(''.join([chunk['url'], suffix]), attrs))
             else:
                 tags.append((
-                    '<script src="{0}" {1}></script>'
-                ).format(''.join([chunk['url'], suffix]), attrs))
+                    '<script src="{0}"{2}{1}></script>'
+                ).format(
+                    ''.join([chunk['url'], suffix]),
+                    attrs,
+                    loader.get_integrity_attr(chunk),
+                ))
         elif chunk['name'].endswith(('.css', '.css.gz')):
             tags.append((
-                '<link href="{0}" rel={2} {1}/>'
-            ).format(''.join([chunk['url'], suffix]), attrs, '"stylesheet"' if not is_preload else '"preload" as="style"'))
+                '<link href="{0}" rel={2}{3}{1}/>'
+            ).format(
+                ''.join([chunk['url'], suffix]),
+                attrs,
+                '"stylesheet"' if not is_preload else '"preload" as="style"',
+                loader.get_integrity_attr(chunk),
+            ))
     return tags
 
 
